..
   .. image:: logo-300px.png
      :alt: histbook
      :target: https://github.com/diana-hep/histbook
      :align: center

histbook
========

.. include:: ../../README.rst
  :start-after: inclusion-marker-1-do-not-remove
  :end-before:  inclusion-marker-3-do-not-remove

Tutorial
--------

See `the homepage <https://github.com/diana-hep/histbook#tutorial>`__ for an introduction and examples.

Interactive tutorial
--------------------

Coming soon on Binder.

Reference documentation
-----------------------

.. toctree::
   :maxdepth: 1

   histograms
   books-of-histograms
   axis-descriptors
